@@ -46,10 +46,12 @@ MAX_LIST_OBJECT_ELEMENTS = 5
 
 @click.group()
 @click.option("-v", "--verbose", is_flag=True)
+@click.option("-y", "--skip-confirm", is_flag=True)
 @click.option("--debug-log-file", is_flag=True)
 @pass_config
-def cli(config: CLIContext, verbose: bool, debug_log_file: bool) -> None:  # noqa: D
+def cli(config: CLIContext, verbose: bool, skip_confirm: bool, debug_log_file: bool) -> None:  # noqa: D
     config.verbose = verbose
+    config.skip_confirm = skip_confirm
 
     if debug_log_file:
         enable_debug_log_file()
@@ -437,7 +439,7 @@ def drop_materialization(
     if end_time and not valid_datetime(end_time):
         click.ClickException("end_time must be valid iso8601 timestamp")
 
-    if start_time is None:
+    if not config.skip_confirm and start_time is None:
         if not click.confirm(
             "You haven't provided a start_time. This means we will drop the materialization from the beginning of time."
             "This may be expensive. Are you sure you want to continue?"
@@ -536,7 +538,7 @@ def materialize(
     if end_time and not valid_datetime(end_time):
         click.ClickException("end_time must be valid iso8601 timestamp")
 
-    if start_time is None:
+    if not config.skip_confirm and start_time is None:
         if not click.confirm(
             "You haven't provided a start_time. This means we will materialize from the beginning of time. This may be expensive. Are you sure you want to continue?"
         ):
