@@ -26,6 +26,7 @@ from .exceptions import QueryRuntimeException
 from .utils import resolve_local_commit_info
 from .helpers import intersect_dict
 from .models import (
+    MqlQueryResultSeries,
     MqlQueryStatus,
     MqlQueryStatusResp,
     QueryResult,
@@ -862,12 +863,12 @@ class MQLInterface(BaseInterface):  # noqa: D
         cache_mode: Optional[CacheMode] = None,
         as_table: Optional[str] = None,
         allow_dynamic_cache: bool = True,
+        result_format: Optional[str] = None,
     ) -> str:
         """Implements CreateMqlQuery mutation in MQL/GQL"""
 
         # TODO: Find a fix to being able to show cli query graph on server logs
         time_series = False
-        result_format = None
         query = gql(
             """
             mutation CreateMqlQueryMutation(
@@ -929,6 +930,22 @@ class MQLInterface(BaseInterface):  # noqa: D
 
         return self.execute(query, variable_values=params)["createMqlQuery"]["id"]
 
+    def query_latest_metric_change(self, metric_name: str) -> str:
+        """Create a query for the latest change in the specified metric"""
+        query = gql(
+            """
+            mutation CreateLatestMetricChangeQuery($input: QueryLatestMetricChangeInput!) {
+                queryLatestMetricChange(input: $input) {
+                    id
+                }
+            }
+            """
+        )
+
+        params = {"input": {"metricName": metric_name}}
+
+        return self.execute(query, variable_values=params)["queryLatestMetricChange"]["id"]
+
     def drop_cache(self) -> bool:  # noqa: D
         """Drops the entire MQL cache. Only do this is the cache is somehow corrupt."""
         query = gql(
@@ -1013,16 +1030,38 @@ class MQLInterface(BaseInterface):  # noqa: D
                     status
                     error
                     sql
+                    resultSource
+                    resultPrimaryTimeGranularity
+                    result {
+                        value
+                        pctChange
+                        delta
+                    }
+                    chartValueMin
+                    chartValueMax
                 }
             }
             """
         )
 
         q = self.execute(query, variable_values={"queryId": query_id})["mqlQuery"]
+
+        result = None
+        if q["result"] is not None:
+            result = [
+                MqlQueryResultSeries(value=v["value"], delta=v["delta"], pct_change=v["pctChange"]) for v in q["result"]
+            ]
+
         return MqlQueryStatusResp(
             query_id=query_id,
             status=MqlQueryStatus[q["status"]],
             error=q["error"] if q["error"] else None,
+            sql=q["sql"],
+            result=result,
+            result_source=q["resultSource"],
+            result_primary_time_granularity=q["resultPrimaryTimeGranularity"],
+            chart_value_min=q["chartValueMin"],
+            chart_value_max=q["chartValueMax"],
         )
 
     def get_queries(self, active_only: bool, limit: Optional[int]) -> List[Query]:
