@@ -215,12 +215,27 @@ class Metric:
         self.description = metadata["description"]
         self.display_name = metadata["displayName"]
         self.tier = metadata["tier"]
-        self.value_format = metadata["valueFormat"]
-        self.is_additive = metadata["isAdditive"]
+        self.value_format = metadata["valueFormat"] if "valueFormat" in metadata else None
+        self.is_additive = metadata["isAdditive"] if "isAdditive" in metadata else None
         self.team_owners = [TeamOwner.from_gql_dict(t["team"]) for t in metadata["teamOwners"]]
         self.user_owners = [UserOwner.from_gql_dict(u["user"]) for u in metadata["userOwners"]]
 
 
+class TimeGranularity(Enum):
+    """For time dimensions, the smallest possible difference between to time values.
+
+    Needed for calculating adjacency when merging 2 different time ranges.
+    """
+
+    # Names are used in parameters to DATE_TRUC, so don't change them.
+    # Values are used to convert user supplied string to enums.
+    DAY = "day"
+    WEEK = "week"
+    MONTH = "month"
+    QUARTER = "quarter"
+    YEAR = "year"
+
+
 class MqlQueryStatus(Enum):
     """The status of queries submitted for execution in the query manager."""
 
@@ -237,11 +252,44 @@ class MqlQueryStatus(Enum):
     TIMEOUT = "TIMEOUT"
 
 
+class MqlQueryResultSource(Enum):
+    """The source of a query's result"""
+
+    DYNAMIC_CACHE = "DYNAMIC_CACHE"
+    DW_MATERIALIZATION = "DW_MATERIALIZATION"
+    FAST_CACHE = "FAST_CACHE"
+    METRICFLOW = "METRICFLOW"
+    NOT_APPLICABLE = "NOT_APPLICABLE"
+    NOT_SPECIFIED = "NOT_SPECIFIED"
+
+
+@dataclass(frozen=True)
+class MqlQueryResultSeries:  # noqa: D
+    value: float
+    delta: float
+    pct_change: float
+
+
 @dataclass(frozen=True)
 class MqlQueryStatusResp:  # noqa: D
     query_id: str
     status: MqlQueryStatus
     error: Optional[str]
+    sql: str
+
+    chart_value_min: Optional[float]
+    chart_value_max: Optional[float]
+    result: Optional[List[MqlQueryResultSeries]]
+    result_source: Optional[MqlQueryResultSource]
+    result_primary_time_granularity: Optional[TimeGranularity]
+
+    def __post_init__(self) -> None:  # noqa: D
+        if not self.is_successful:
+            assert self.chart_value_min is None
+            assert self.chart_value_min is None
+            assert self.result is None
+            assert self.result_source is None
+            assert self.result_primary_time_granularity is None
 
     @property
     def is_complete(self) -> bool:
@@ -291,19 +339,14 @@ class CacheMode(Enum):
         return CacheMode.READWRITE
 
 
-class TimeGranularity(Enum):
-    """For time dimensions, the smallest possible difference between to time values.
+@dataclass(frozen=True)
+class CompletedQueryScalarValues:
+    """Scalar values returned by a completed query"""
 
-    Needed for calculating adjacency when merging 2 different time ranges.
-    """
-
-    # Names are used in parameters to DATE_TRUC, so don't change them.
-    # Values are used to convert user supplied string to enums.
-    DAY = "day"
-    WEEK = "week"
-    MONTH = "month"
-    QUARTER = "quarter"
-    YEAR = "year"
+    query_id: str
+    chart_value_min: float
+    chart_value_max: float
+    result_primary_time_granularity: TimeGranularity
 
 
 @dataclass(frozen=True)
