@@ -24,6 +24,7 @@ from .models import (
     UserState,
 )
 from .interfaces import DWValidationType, MQLInterface
+from .exceptions import QueryRuntimeException
 
 
 class MQLClient:
@@ -37,7 +38,7 @@ class MQLClient:
         use_async: bool = False,
         target_org_id: Optional[int] = None,  # no-op for non-admin use
     ) -> None:
-        self.context = TransformAuth(api_key, mql_server_url, override_config, use_async)
+        self.context = TransformAuth(api_key, mql_server_url, override_config, use_async, target_org_id)
 
     def create_query(  # noqa: D
         self,
@@ -53,6 +54,7 @@ class MQLClient:
         cache_mode: Optional[str] = None,
         as_table: Optional[str] = None,
         allow_dynamic_cache: bool = True,
+        result_format: Optional[str] = None,
     ) -> MqlQueryStatusResp:
         """Builds a query in MQL and returns a MqlQueryStatusResp detailing the results."""
         model_key = self.get_model_key(model_key_id) if model_key_id else None
@@ -69,9 +71,15 @@ class MQLClient:
             CacheMode(cache_mode) if cache_mode else None,
             as_table,
             allow_dynamic_cache,
+            result_format,
         )
         return self.context.mql_client.get_query_status(query_id)
 
+    def query_latest_metric_change(self, metric_name: str) -> MqlQueryStatusResp:
+        """Create a query for the latest change in the specified metric"""
+        query_id = self.context.mql_client.query_latest_metric_change(metric_name)
+        return self.context.mql_client.get_query_status(query_id)
+
     def query(  # noqa: D
         self,
         metrics: List[str],
@@ -111,6 +119,58 @@ class MQLClient:
         )
         return self.get_query_dataframe(query_id, timeout)
 
+    def query_safe(  # noqa: D
+        self,
+        metrics: List[str],
+        dimensions: List[str],
+        model_key_id: Optional[int] = None,
+        where: Optional[str] = None,
+        time_constraint: Optional[str] = None,
+        time_granularity: Optional[str] = None,
+        time_comparison: Optional[str] = None,
+        order: Optional[List[str]] = None,
+        limit: Optional[str] = None,
+        cache_mode: Optional[str] = None,
+        as_table: Optional[str] = None,
+        allow_dynamic_cache: bool = True,
+        timeout: Optional[int] = None,
+    ) -> MqlQueryStatusResp:
+        """Builds a query in MQL and returns a MqlQueryStatusResp.
+
+        Instead of throwing if unable to get query, it returns a response class to show the details of the query.
+        """
+        model_key = self.get_model_key(model_key_id) if model_key_id else None
+        query_id = self.context.mql_client.create_query(
+            metrics,
+            dimensions,
+            model_key,
+            where,
+            time_constraint,
+            TimeGranularity(time_granularity) if time_granularity else None,
+            PercentChange(time_comparison) if time_comparison else None,
+            order,
+            None if limit in [INF, NEGATIVE_ONE, int(NEGATIVE_ONE)] else limit,
+            CacheMode(cache_mode) if cache_mode else None,
+            as_table,
+            allow_dynamic_cache,
+        )
+        try:
+            result = self.get_query_dataframe(query_id, timeout)
+        except QueryRuntimeException:
+            result = None
+        resp = self.context.mql_client.get_query_status(query_id)
+        return MqlQueryStatusResp(
+            query_id=resp.query_id,
+            status=resp.status,
+            error=resp.error,
+            sql=resp.sql,
+            result=result,
+            chart_value_max=resp.chart_value_max,
+            chart_value_min=resp.chart_value_min,
+            result_source=resp.result_source,
+            result_primary_time_granularity=resp.result_primary_time_granularity,
+        )
+
     def list_queries(self, active_only: bool, limit: Optional[int] = None) -> List[Query]:
         """Retrieve a list of queries from MQL server."""
         return self.context.mql_client.get_queries(active_only=active_only, limit=limit)
